@@ -912,7 +912,7 @@ function GenomeSSRController($scope, $routeParams, $http, $location) {
     $scope.is_donor_circular = false;
     $scope.events = undefined;
     $scope.waiting = false;
-    $scope.previewed = false;
+    $scope.previewed_json = undefined;
     $scope.errors = undefined;
   
     $http.get("/edge/genomes/" + $scope.genomeId + "/").success(function(data) {
@@ -921,31 +921,32 @@ function GenomeSSRController($scope, $routeParams, $http, $location) {
 
     $scope.PreviewSSR = function() {
         console.log($scope.new_genome_name);
-        if (($scope.reaction === undefined) || ($scope.new_genome_name === undefined) || ($scope.donor === "")) {
-            $scope.previewed = undefined;
-            $scope.errors = "Please specify (1) reaction, (2) new genome name, and (3) donor sequence";
+        if (($scope.reaction === undefined) || ($scope.new_genome_name === undefined)) {
+            $scope.previewed_json = undefined;
+            $scope.errors = "Please specify (1) reaction and (2) new genome name";
         } else {
             $scope.waiting = true;
             $scope.donor = $scope.donor.replace(/\s+/g, "");
-            var data = JSON.stringify({
+            var previewed_json = {
                 donor: $scope.donor,
                 is_donor_circular: $scope.is_donor_circular,
                 reaction: $scope.reaction,
                 genome_name: $scope.new_genome_name,
                 create: false
-            });
+            }
+            var data = JSON.stringify(previewed_json);
             $http
                 .post("/edge/genomes/" + $scope.genomeId + "/ssr/", data)
                 .success(function(data) {
+                    $scope.previewed_json = previewed_json;
                     $scope.events = data;
                     $scope.waiting = false;
-                    $scope.previewed = true;
                     $scope.errors = undefined;
                 })
                 .error(function(data, status, headers, config) {
+                    $scope.previewed_json = undefined;
                     $scope.events = undefined;
                     $scope.waiting = false;
-                    $scope.previewed = false;
                     $scope.errors = data;
                 });
         };
@@ -953,14 +954,8 @@ function GenomeSSRController($scope, $routeParams, $http, $location) {
 
     $scope.SSR = function() {
         $scope.waiting = true;
-        $scope.donor = $scope.donor.replace(/\s+/g, "");
-        var data = JSON.stringify({
-            donor: $scope.donor,
-            is_donor_circular: $scope.is_donor_circular,
-            reaction: $scope.reaction,
-            genome_name: $scope.new_genome_name,
-            create: true
-        });
+        $scope.previewed_json.create = true;
+        var data = JSON.stringify($scope.previewed_json);
         $http
             .post("/edge/genomes/" + $scope.genomeId + "/ssr/", data)
             .success(function(genome) {
