@@ -44,8 +44,8 @@ class GenomePcrTest(TestCase):
             r[0], "".join([p1, middle, str(Seq(p2).reverse_complement())])
         )
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 121)  # multiple blast results for each primer
-        self.assertEquals(len(r[2]), 143)  # multiple blast results for each primer
+        self.assertEquals(len(r[1]), 6)  # multiple blast results for each primer
+        self.assertEquals(len(r[2]), 6)  # multiple blast results for each primer
         self.assertEquals(r[3]["fragment_name"], g.fragments.all()[0].name)
         self.assertEquals(r[3]["fragment_id"], g.fragments.all()[0].id)
         self.assertEquals(
@@ -138,9 +138,9 @@ class GenomePcrTest(TestCase):
             r[0], "".join([p1, middle, str(Seq(p2).reverse_complement())])
         )
         # 2 binding sites + 2*5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 127)  # multiple blast results for each primer
+        self.assertEquals(len(r[1]), 12)  # multiple blast results for each primer
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[2]), 143)  # multiple blast results for this primer
+        self.assertEquals(len(r[2]), 6)  # multiple blast results for this primer
         self.assertEquals(r[3]["fragment_name"], g.fragments.all()[0].name)
         self.assertEquals(r[3]["fragment_id"], g.fragments.all()[0].id)
         self.assertEquals(
@@ -161,14 +161,14 @@ class GenomePcrTest(TestCase):
         r = pcr_from_genome(g, p1, p2)
         self.assertEquals(r[0], None)
         # 2 binding sites + 2*5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 97)  # multiple blast results for each primer
-        self.assertEquals(len(r[2]), 101)  # multiple blast results for each primer
+        self.assertEquals(len(r[1]), 12)  # multiple blast results for each primer
+        self.assertEquals(len(r[2]), 12)  # multiple blast results for each primer
 
     def test_pcr_does_not_produce_product_when_primer_binding_site_is_too_small(self):
         upstream = get_random_sequence(2000)
         p1_bs = "catagcgcacaggacgcggag"
         middle = "cggcacctgtgagccg"
-        p2_bs = "gctagcatca"
+        p2_bs = "gctagcatcaa"
         downstream = get_random_sequence(2000)
         template = "".join([upstream, p1_bs, middle, p2_bs, downstream])
         p1 = "aaaaaaaaaa" + p1_bs
@@ -178,8 +178,8 @@ class GenomePcrTest(TestCase):
         r = pcr_from_genome(g, p1, p2)
         self.assertEquals(r[0], None)
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 121)
-        self.assertEquals(len(r[2]), 65)
+        self.assertEquals(len(r[1]), 6)
+        self.assertEquals(len(r[2]), 6)
 
     def test_pcr_does_not_produce_product_when_primer_binding_site_has_too_many_mutations(
         self,
@@ -210,8 +210,8 @@ class GenomePcrTest(TestCase):
         r = pcr_from_genome(g, p1, p2)
         self.assertEquals(r[0], None)
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 114)
-        self.assertEquals(len(r[2]), 128)
+        self.assertEquals(len(r[1]), 0)
+        self.assertEquals(len(r[2]), 6)
 
         g = self.build_genome(False, template)
         r = pcr_from_genome(g, p1_good, p2)
@@ -219,8 +219,8 @@ class GenomePcrTest(TestCase):
             r[0], "".join([p1_good, middle, str(Seq(p2).reverse_complement())])
         )
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 121)
-        self.assertEquals(len(r[2]), 128)
+        self.assertEquals(len(r[1]), 6)
+        self.assertEquals(len(r[2]), 6)
 
     def test_pcr_does_not_produce_product_when_primer_binds_to_different_fragments(
         self,
@@ -239,8 +239,8 @@ class GenomePcrTest(TestCase):
         r = pcr_from_genome(g, p1, p2)
         self.assertEquals(r[0], None)
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 126)
-        self.assertEquals(len(r[2]), 143)
+        self.assertEquals(len(r[1]), 6)
+        self.assertEquals(len(r[2]), 6)
 
     def test_pcr_does_produce_product_when_duplicate_regions_on_different_genome(self):
         upstream = get_random_sequence(2000)
@@ -258,16 +258,16 @@ class GenomePcrTest(TestCase):
         r = pcr_from_genome(g1, p1, p2)
         self.assertEquals(r[0], None)
         # 2 binding sites + 2*5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 118)  # multiple blast results for each primer
-        self.assertEquals(len(r[2]), 62)  # multiple blast results for each primer
+        self.assertEquals(len(r[1]), 12)  # multiple blast results for each primer
+        self.assertEquals(len(r[2]), 12)  # multiple blast results for each primer
 
         r = pcr_from_genome(g2, p1, p2)
         self.assertEquals(
             r[0], "".join([p1, middle, str(Seq(p2).reverse_complement())])
         )
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(r[1]), 121)
-        self.assertEquals(len(r[2]), 143)
+        self.assertEquals(len(r[1]), 6)
+        self.assertEquals(len(r[2]), 6)
 
     def test_pcr_api(self):
         upstream = get_random_sequence(2000)
@@ -293,14 +293,14 @@ class GenomePcrTest(TestCase):
             d[0], "".join([p1, middle, str(Seq(p2).reverse_complement())])
         )
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(d[1]), 121)
+        self.assertEquals(len(d[1]), 6)
         # first set of binding location = max primer binding location
         self.assertEquals(d[1][0]["subject_start"], len(upstream) + 1)
         self.assertEquals(d[1][0]["subject_end"], len(upstream) + len(p1_bs))
         self.assertEquals(d[1][0]["query_start"], len(p1) - len(p1_bs) + 1)
         self.assertEquals(d[1][0]["query_end"], len(p1))
         # 1 binding site + 5 partial primer binding sites (-15 to -20 bps of primers)
-        self.assertEquals(len(d[2]), 143)
+        self.assertEquals(len(d[2]), 6)
         # first set of binding location = max primer binding location
         self.assertEquals(d[2][0]["subject_start"], len(template) - len(downstream))
         self.assertEquals(
