@@ -2,21 +2,24 @@ from django.conf.urls import url
 from django.views.generic.base import TemplateView
 
 from edge.views import (
-    FragmentView,
+    FragmentAnnotateChunksView,
+    FragmentAnnotationsView,
     FragmentListView,
     FragmentSequenceView,
-    FragmentAnnotationsView,
-    FragmentAnnotateChunksView,
-    GenomeDeriveView,
-    GenomeView,
-    GenomeListView,
+    FragmentView,
     GenomeAnnotationsView,
-    GenomeFragmentListView,
     GenomeBlastView,
+    GenomeCrisprDSBView,
+    GenomeDeriveView,
+    GenomeDiffView,
+    GenomeFragmentListView,
+    GenomeListView,
     GenomePcrView,
     GenomeRecombinationView,
-    GenomeCrisprDSBView,
-    genome_export,
+    GenomeSSRView,
+    GenomeView,
+    genome_fasta_export,
+    genome_gff_export,
     genome_import,
 )
 
@@ -73,6 +76,11 @@ urlpatterns = [
         GenomeRecombinationView.as_view(),
         name="genome_recombination",
     ),
+    url(
+        r"^genomes/(?P<genome_id>\d+)/ssr/$",
+        GenomeSSRView.as_view(),
+        name="genome_ssr",
+    ),
     url(
         r"^genomes/(?P<genome_id>\d+)/crispr/dsb/$",
         GenomeCrisprDSBView.as_view(),
@@ -83,5 +91,24 @@ urlpatterns = [
         GenomeDeriveView.as_view(),
         name="derive-genome-with-new-fragments",
     ),
-    url(r"^genomes/(?P<genome_id>\d+)/export/$", genome_export),
+    url(
+        r"^genomes/(?P<child_genome_id>\d+)/(?P<parent_genome_id>\d+)/genome-coordinate-diff/$",
+        GenomeDiffView.as_view(),
+        name="genome-coordinate-diff",
+    ),
+    url(
+        r"^genomes/(?P<genome_id>\d+)/export/$",
+        genome_gff_export,
+        name="old-genome-gff-export",
+    ),
+    url(
+        r"^genomes/(?P<genome_id>\d+)/export-fasta/$",
+        genome_fasta_export,
+        name="genome-fasta-export",
+    ),
+    url(
+        r"^genomes/(?P<genome_id>\d+)/export-gff/$",
+        genome_gff_export,
+        name="genome-gff-export",
+    ),
 ]
